searchData={"items":[{"type":"module","title":"WiseGPTEx","doc":"Documentation for `WiseGPTEx`.\n\nThis module provides functions to obtain the best completion from the OpenAI models (default: \"gpt-3.5-turbo\") using the OpenAI API completions endpoint (`https://api.openai.com/v1/chat/completions`).\nThe `get_best_completion/2` and `get_best_completion_with_resolver/2` functions take a question and an optional list of options to configure the API request. `get_best_completion_with_resolver/2` also involves a secondary step to resolve the best completion among the options, which leads to an additional API call for a more accurate response.","ref":"WiseGPTEx.html"},{"type":"module","title":"Examples - WiseGPTEx","doc":"Basic usage:\n\n    iex> WiseGPTEx.get_best_completion(\"What is the capital of France?\")\n    {:ok, \"Paris\"}\n\n    iex> WiseGPTEx.get_best_completion_with_resolver(\"What is the capital of France?\")\n    {:ok, \"Paris\"}\n\nUsing a raw completion:\n\n    iex> messages = [\n    ...>   %{\"role\" => \"system\", \"content\" => \"You are High School Geography Teacher\"},\n    ...>   %{\"role\" => \"user\", \"content\" => \"What was the capital of France in 15th century?\"}\n    ...> ]\n    ...> WiseGPTEx.openai_completion(messages)\n    {:ok, \"The capital of France in the 15th century was Paris.\"}\n\nUsing all available options:\n\n    iex> opts = [model: \"gpt-4\", temperature: 0.7, num_completions: 5, timeout: 3_600_000]\n    iex> WiseGPTEx.get_best_completion(\"What is the capital of France?\", opts)\n    {:ok, \"Paris\"}\n\n    iex> WiseGPTEx.get_best_completion_with_resolver(\"What is the capital of France?\", opts)\n    {:ok, \"Paris\"}\n\nNote that the examples for the `get_best_completion_with_resolver/2` function are similar to `get_best_completion/2`.\nThis is because the difference between these two functions is in the method of how they select the best completion, not in their usage or the nature of their inputs or outputs.\nThe `get_best_completion_with_resolver/2` function will perform an additional API call to get a more accurate completion, which can be beneficial for complex or ambiguous queries.\n\nAnthropic API usage:\n\n    iex> WiseGPTEx.anthropic_completion(\"Why is the sky blue?\")\n    {:ok, \"The sky is blue because... [detailed explanation]\"}","ref":"WiseGPTEx.html#module-examples"},{"type":"module","title":"Options - WiseGPTEx","doc":"The following options can be passed to the `get_best_completion/2` and `get_best_completion_with_resolver/2` functions:\n\n  * `:model` - The name of the model to use (default: \"gpt-3.5-turbo\"). All OpenAI models are supported.\n  * `:temperature` - Controls the randomness of the model's output. Higher values result in more diverse responses (default: 0.5).\n  * `:num_completions` - The number of completions to generate (default: 3).\n  * `:timeout` - The maximum time in milliseconds to wait for a response from the OpenAI API (default: 3_600_000 ms, or 60 minutes).\n\nFor `anthropic_completion/2`, the following options can be passed:\n\n  * `:model` - The version of the Claude model to use (default: \"claude-2\").\n  * `:temperature` - Controls the randomness of the model's output (default: 0.1).\n  * `:max_tokens_to_sample` - Maximum number of tokens to generate (default: 100,000).\n  * `:timeout` - Maximum time in milliseconds to wait for a response (default: 3,600,000 ms, or 60 minutes).","ref":"WiseGPTEx.html#module-options"},{"type":"function","title":"WiseGPTEx.anthropic_completion/2","doc":"Retrieves a completion from the Anthropic API using the Claude model.","ref":"WiseGPTEx.html#anthropic_completion/2"},{"type":"function","title":"Params: - WiseGPTEx.anthropic_completion/2","doc":"- `message`: A string containing the prompt or question.\n- `opts`: A keyword list of options to configure the API request.","ref":"WiseGPTEx.html#anthropic_completion/2-params"},{"type":"function","title":"Returns: - WiseGPTEx.anthropic_completion/2","doc":"- `{:ok, binary()}`: The completion for the given prompt.\n- `{:error, any()}`: An error message in case of failure.\n\nThis function provides a direct way to interact with the Anthropic API, allowing for detailed control over the completion request.","ref":"WiseGPTEx.html#anthropic_completion/2-returns"},{"type":"function","title":"Example: - WiseGPTEx.anthropic_completion/2","doc":"```elixir\niex> WiseGPTEx.anthropic_completion(\"Why is the sky blue?\")\n{:ok, \"The sky is blue because... [detailed explanation]\"}\n```","ref":"WiseGPTEx.html#anthropic_completion/2-example"},{"type":"function","title":"WiseGPTEx.get_best_completion/2","doc":"`get_best_completion/2` attempts to answer a given question using OpenAI's completion endpoint.","ref":"WiseGPTEx.html#get_best_completion/2"},{"type":"function","title":"Params: - WiseGPTEx.get_best_completion/2","doc":"- `question`: a binary string containing the question to be answered\n- `opts`: a keyword list of options to configure the API request","ref":"WiseGPTEx.html#get_best_completion/2-params"},{"type":"function","title":"Returns: - WiseGPTEx.get_best_completion/2","doc":"- `{:ok, binary()}`: the best completion for the given question\n- `{:error, any()}`: an error message in the case of failure","ref":"WiseGPTEx.html#get_best_completion/2-returns"},{"type":"function","title":"Example: - WiseGPTEx.get_best_completion/2","doc":"```elixir\niex> WiseGPTEx.get_best_completion(\"What is the capital of France?\")\n{:ok, \"Paris\"}\n```","ref":"WiseGPTEx.html#get_best_completion/2-example"},{"type":"function","title":"Options: - WiseGPTEx.get_best_completion/2","doc":"The function accepts the following options:\n\n- `:model` - The name of the model to use (default: \"gpt-3.5-turbo\"). All OpenAI models are supported.\n- `:temperature` - Controls the randomness of the model's output. Higher values result in more diverse responses (default: 0.5).\n- `:num_completions` - The number of completions to generate (default: 3).\n- `:timeout` - The maximum time in milliseconds to wait for a response from the OpenAI API (default: 3_600_000 ms, or 60 minutes).","ref":"WiseGPTEx.html#get_best_completion/2-options"},{"type":"function","title":"WiseGPTEx.get_best_completion_with_resolver/2","doc":"`get_best_completion_with_resolver/2` is similar to `get_best_completion/2` but uses a secondary step to resolve the best completion among the options.\n\nThis function will perform an additional API call to get a more accurate completion, which can be beneficial for complex or ambiguous queries.","ref":"WiseGPTEx.html#get_best_completion_with_resolver/2"},{"type":"function","title":"Params: - WiseGPTEx.get_best_completion_with_resolver/2","doc":"- `question`: a binary string containing the question to be answered\n- `opts`: a keyword list of options to configure the API request","ref":"WiseGPTEx.html#get_best_completion_with_resolver/2-params"},{"type":"function","title":"Returns: - WiseGPTEx.get_best_completion_with_resolver/2","doc":"- `{:ok, binary()}: the best completion for the given question\n- `{:error, any()}: an error message in the case of failure","ref":"WiseGPTEx.html#get_best_completion_with_resolver/2-returns"},{"type":"function","title":"Example: - WiseGPTEx.get_best_completion_with_resolver/2","doc":"```elixir\niex> WiseGPTEx.get_best_completion_with_resolver(\"What is the capital of France?\")\n{:ok, \"Paris\"}\n```","ref":"WiseGPTEx.html#get_best_completion_with_resolver/2-example"},{"type":"function","title":"Options: - WiseGPTEx.get_best_completion_with_resolver/2","doc":"The function accepts the following options:\n\n- `:model` - The name of the model to use (default: \"gpt-3.5-turbo\"). All OpenAI models are supported.\n- `:temperature - Controls the randomness of the model's output. Higher values result in more diverse responses (default: 0.5).\n- `:num_completions` - The number of completions to generate (default: 3).\n- `:timeout` - The maximum time in milliseconds to wait for a response from the OpenAI API (default: 3_600_000 ms, or 60 minutes).","ref":"WiseGPTEx.html#get_best_completion_with_resolver/2-options"},{"type":"function","title":"WiseGPTEx.openai_completion/2","doc":"Gets a raw completion from the OpenAI API without additional prompting.","ref":"WiseGPTEx.html#openai_completion/2"},{"type":"function","title":"Params: - WiseGPTEx.openai_completion/2","doc":"- `messages`: A list of messages to send to the API. Each message should be a map with keys \"role\" and \"content\", for example:\n```elixir\n    iex> messages = [\n    ...>   %{\"role\" => \"system\", \"content\" => \"You are High School Geography Teacher\"},\n    ...>   %{\"role\" => \"user\", \"content\" => \"What was the capital of France in 15th century?\"}\n    ...> ]\n```\n- `opts`: a keyword list of options to configure the API request","ref":"WiseGPTEx.html#openai_completion/2-params"},{"type":"function","title":"Returns: - WiseGPTEx.openai_completion/2","doc":"- `{:ok, binary()}`: the completion for the given question\n- `{:error, any()}`: an error message in the case of failure\n\nThis allows you to customize the conversation sent to the API without any additional prompting added.","ref":"WiseGPTEx.html#openai_completion/2-returns"},{"type":"function","title":"Example: - WiseGPTEx.openai_completion/2","doc":"```elixir\n    iex> messages = [\n    ...>   %{\"role\" => \"system\", \"content\" => \"You are High School Geography Teacher\"},\n    ...>   %{\"role\" => \"user\", \"content\" => \"What was the capital of France in 15th century?\"}\n    ...> ]\n    ...> WiseGPTEx.openai_completion(messages)\n    {:ok, \"The capital of France in the 15th century was Paris.\"}\n```","ref":"WiseGPTEx.html#openai_completion/2-example"},{"type":"module","title":"WiseGPTEx.AnthropicHTTPClient","doc":"Documentation for `WiseGPTEx.AnthropicHTTPClient`.\n\nThis module provides functionalities to interact with the Anthropic API, specifically to utilize the Claude model for generating responses. It is designed to be used internally within the `WiseGPTEx` module and is not intended for direct usage.\n\nKey functions include:\n\n  * `complete/2` - Sends a prompt to the Anthropic API and receives a completion using the Claude model. It allows customization of various parameters such as model, temperature, and maximum tokens.\n\n  **NOTE:** This module is designed to offer a straightforward interface to the Anthropic API, focusing on raw API calls with minimal additional processing. It provides direct and flexible access to the Claude model's capabilities.\n\nRefer to the Claude API documentation for more details: https://docs.anthropic.com/claude/reference/complete_post","ref":"WiseGPTEx.AnthropicHTTPClient.html"},{"type":"function","title":"WiseGPTEx.AnthropicHTTPClient.complete/2","doc":"Completes a prompt using Claude.\nClaude API docs: https://docs.anthropic.com/claude/reference/complete_post\n\nmodel - string | required\nThe model that will complete your prompt.\nAs we improve Claude, we develop new versions of it that you can query.\nThis parameter controls which version of Claude answers your request.\nRight now we are offering two model families: Claude, and Claude Instant.\nYou can use them by setting model to \"claude-2\" or \"claude-instant-1\", respectively.\n\nprompt - blob | required\nThe prompt that you want Claude to complete.\nFor proper response generation you will need to format your prompt as follows:\n```JavaScript\nconst userQuestion = r\"Why is the sky blue?\";\nconst prompt = `\n\nHuman: ${userQuestion}\n\nAssistant:`;\n```\n\nmax_tokens_to_sample - integer | required\nThe maximum number of tokens to generate before stopping.\nNote that our models may stop before reaching this maximum.\nThis parameter only specifies the absolute maximum number of tokens to generate.\n\nstop_sequences - array of strings\nSequences that will cause the model to stop generating completion text.\nOur models stop on \"\n\nHuman:\", and may include additional built-in stop sequences in the future.\nBy providing the stop_sequences parameter, you may include additional strings that will cause the model to stop generating.\n\ntemperature - number\nAmount of randomness injected into the response.\nDefaults to 1. Ranges from 0 to 1.\nUse temp closer to 0 for analytical / multiple choice, and closer to 1 for creative and generative tasks.\n\ntop_p - number\nUse nucleus sampling.\nIn nucleus sampling, we compute the cumulative distribution over all the options for each subsequent token\n in decreasing probability order and cut it off once it reaches a particular probability specified by top_p.\nYou should either alter temperature or top_p, but not both.\n\ntop_k - integer\nOnly sample from the top K options for each subsequent token.\nUsed to remove \"long tail\" low probability responses.\n\nmetadata - object\nAn object describing metadata about the request.\n  user_id - string\n  An external identifier for the user who is associated with the request.\n  This should be a uuid, hash value, or other opaque identifier.\n  Anthropic may use this id to help detect abuse.\n  Do not include any identifying information such as name, email address, or phone number.\n\nstream - boolean\nWhether to incrementally stream the response using server-sent events.","ref":"WiseGPTEx.AnthropicHTTPClient.html#complete/2"},{"type":"module","title":"WiseGPTEx.AnthropicUtils","doc":"Provides utility functions for processing responses from the Anthropic API.","ref":"WiseGPTEx.AnthropicUtils.html"},{"type":"function","title":"WiseGPTEx.AnthropicUtils.extract_complete/1","doc":"Extracts the completion from the response body of the Anthropic API.\n\nThis function parses the response from the API, focusing on extracting the 'completion' field. It handles both successful and error responses, returning a string that represents the completion or an error message.\n\nIn the case of successful responses, it returns the 'completion' field's content. For error responses, it returns a formatted error message.","ref":"WiseGPTEx.AnthropicUtils.html#extract_complete/1"},{"type":"function","title":"Examples - WiseGPTEx.AnthropicUtils.extract_complete/1","doc":"Successful response:\n    iex> response = %{\n    ...>   \"completion\" => \" Okay, let's solve this step-by-step:\\n42 * 38\\n= 42 * (30 + 8) \\n= 42 * 30 + 42 * 8\\n= 1260 + 336\\n= 1596.\",\n    ...>   \"stop_reason\" => \"stop_sequence\",\n    ...>   \"model\" => \"claude-2.0\",\n    ...>   \"stop\" => \"\\n\\nHuman:\",\n    ...>   \"log_id\" => \"00c6b4ba97de04c5329dc50c0124e4814dfc3252d751afd55bcfaad44023be6d\"\n    ...> }\n    ...> WiseGPTEx.AnthropicUtils.extract_complete(response)\n    \" Okay, let's solve this step-by-step:\\n42 * 38\\n= 42 * (30 + 8) \\n= 42 * 30 + 42 * 8\\n= 1260 + 336\\n= 1596.\"\n\nError response:\n    iex> error_response = %{\n    ...>   \"error\" => %{\n    ...>     \"type\" => \"not_found_error\",\n    ...>     \"message\" => \"Not found\"\n    ...>   }\n    ...> }\n    ...> WiseGPTEx.AnthropicUtils.extract_complete(error_response)\n    \"Error: %{\\\"message\\\" => \\\"Not found\\\", \\\"type\\\" => \\\"not_found_error\\\"}\"","ref":"WiseGPTEx.AnthropicUtils.html#extract_complete/1-examples"},{"type":"module","title":"WiseGPTEx.OpenAIHTTPClient","doc":"Documentation for `WiseGPTEx.OpenAIHTTPClient`.\n\nThis module contains functions to interact with the OpenAI API to get completions with reasoning and determine the best completion. It is used internally by the `WiseGPTEx` module and is not intended to be called directly by users.\n\nThe main functions in this module are:\n\n  * `get_completions_with_reasoning/2` - Retrieves completions with reasoning from the OpenAI API based on a given message and an optional list of options.\n  * `get_best_completion/3` - Determines the best completion from a list of completions and an optional list of options.\n  * `completion/2` - Gets a raw completion from the API based on given messages, without additional prompting.\n\n  **NOTE:**  `completion/2` allows sending custom conversations with both role and content to the API, while the other functions add extra prompting to request reasoning, disambiguation, etc.","ref":"WiseGPTEx.OpenAIHTTPClient.html"},{"type":"function","title":"WiseGPTEx.OpenAIHTTPClient.completion/2","doc":"","ref":"WiseGPTEx.OpenAIHTTPClient.html#completion/2"},{"type":"function","title":"WiseGPTEx.OpenAIHTTPClient.get_best_completion/3","doc":"","ref":"WiseGPTEx.OpenAIHTTPClient.html#get_best_completion/3"},{"type":"function","title":"WiseGPTEx.OpenAIHTTPClient.get_completions_with_reasoning/2","doc":"","ref":"WiseGPTEx.OpenAIHTTPClient.html#get_completions_with_reasoning/2"},{"type":"function","title":"WiseGPTEx.OpenAIHTTPClient.get_resolver_completion/4","doc":"","ref":"WiseGPTEx.OpenAIHTTPClient.html#get_resolver_completion/4"},{"type":"module","title":"WiseGPTEx.OpenAIUtils","doc":"Provides facilities for processing some of the responses from third party APIs.","ref":"WiseGPTEx.OpenAIUtils.html"},{"type":"function","title":"WiseGPTEx.OpenAIUtils.extract_completion/1","doc":"A function that takes a list of completions and returns the content of the first one that finished.","ref":"WiseGPTEx.OpenAIUtils.html#extract_completion/1"},{"type":"function","title":"Example - WiseGPTEx.OpenAIUtils.extract_completion/1","doc":"iex> body = %{\n    ...>   \"choices\" => [\n    ...>     %{\n    ...>       \"finish_reason\" => \"stop\",\n    ...>       \"index\" => 0,\n    ...>       \"message\" => %{\n    ...>         \"content\" => \"Correct Answer: Option 1.\",\n    ...>         \"role\" => \"assistant\"\n    ...>       }\n    ...>     }\n    ...>   ]\n    ...> }\n    ...> WiseGPTEx.OpenAIUtils.extract_completion(body)\n    \"Correct Answer: Option 1.\"","ref":"WiseGPTEx.OpenAIUtils.html#extract_completion/1-example"},{"type":"function","title":"WiseGPTEx.OpenAIUtils.extract_completions/1","doc":"A function that takes a list of completions and returns the content of all that finished.","ref":"WiseGPTEx.OpenAIUtils.html#extract_completions/1"},{"type":"function","title":"Example - WiseGPTEx.OpenAIUtils.extract_completions/1","doc":"iex> body = %{\n    ...>   \"choices\" => [\n    ...>     %{\n    ...>       \"finish_reason\" => \"stop\",\n    ...>       \"index\" => 0,\n    ...>       \"message\" => %{\n    ...>         \"content\" => \"First, 456 * 23421 = 54,456.\",\n    ...>         \"role\" => \"assistant\"\n    ...>       }\n    ...>     },\n    ...>     %{\n    ...>       \"finish_reason\" => \"stop\",\n    ...>       \"index\" => 1,\n    ...>       \"message\" => %{\n    ...>         \"content\" => \"Second, we get the answer: 10,686,876.\",\n    ...>         \"role\" => \"assistant\"\n    ...>       }\n    ...>     }\n    ...>   ]\n    ...> }\n    ...> WiseGPTEx.OpenAIUtils.extract_completions(body)\n    [\"First, 456 * 23421 = 54,456.\", \"Second, we get the answer: 10,686,876.\"]","ref":"WiseGPTEx.OpenAIUtils.html#extract_completions/1-example"},{"type":"function","title":"WiseGPTEx.OpenAIUtils.prepare_completion_options/1","doc":"A function that takes a list of completions and prepares them as answer options.\nEach option is prefixed with \"Answer Option\" followed by its index in the list, and all options are joined together with newline.","ref":"WiseGPTEx.OpenAIUtils.html#prepare_completion_options/1"},{"type":"function","title":"Example - WiseGPTEx.OpenAIUtils.prepare_completion_options/1","doc":"iex> completions = [\"PHP\", \"Elixir\", \"Go\"]\n    ...> WiseGPTEx.OpenAIUtils.prepare_completion_options(completions)\n    \"Answer Option 1: PHP\\nAnswer Option 2: Elixir\\nAnswer Option 3: Go\"","ref":"WiseGPTEx.OpenAIUtils.html#prepare_completion_options/1-example"},{"type":"function","title":"WiseGPTEx.OpenAIUtils.reasoning_prompt/1","doc":"A function that takes a message and returns a prompt with a reasoning template.","ref":"WiseGPTEx.OpenAIUtils.html#reasoning_prompt/1"},{"type":"function","title":"Example - WiseGPTEx.OpenAIUtils.reasoning_prompt/1","doc":"iex> WiseGPTEx.OpenAIUtils.reasoning_prompt(\"What is 2+2?\")\n    \"Question: What is 2+2?\\nAnswer: Let's work this out in a step by step way to be sure we have the right answer.\"","ref":"WiseGPTEx.OpenAIUtils.html#reasoning_prompt/1-example"},{"type":"function","title":"WiseGPTEx.OpenAIUtils.researcher_prompt/2","doc":"A function that takes a message and completions with reasoning, and returns a string prompt for a researcher.\n\nThe researcher is tasked with investigating the answer options provided, listing the flaws and faulty logic of each answer option.","ref":"WiseGPTEx.OpenAIUtils.html#researcher_prompt/2"},{"type":"function","title":"Example - WiseGPTEx.OpenAIUtils.researcher_prompt/2","doc":"iex> message = \"What is the capital of France?\"\n    ...> completions_with_reasoning = \"Option 1: Paris - This is the correct answer. Paris is the capital of France.\\nOption 2: London - This is incorrect. London is the capital of the United Kingdom, not France.\"\n    ...> WiseGPTEx.OpenAIUtils.researcher_prompt(message, completions_with_reasoning)\n    \"What is the capital of France?\\n\\nOption 1: Paris - This is the correct answer. Paris is the capital of France.\\nOption 2: London - This is incorrect. London is the capital of the United Kingdom, not France.\\n\\nYou are researcher tasked with investigating the answer options provided. List the flaws and faulty logic of each answer option. Let's work this out in a step by step way to be sure we have all the errors\\n\\n**Answer format:**\\nCorrect Answer:  \\n**If there are multiple correct answers, pick the first one.**\"","ref":"WiseGPTEx.OpenAIUtils.html#researcher_prompt/2-example"},{"type":"function","title":"WiseGPTEx.OpenAIUtils.resolver_prompt/0","doc":"A simple function that returns a static string.\nThis string serves as an instruction for a \"resolver\" role,\noutlining the tasks it needs to perform.\n\nThese tasks include:\n\n  1. Identifying the best answer from a set of options.\n  2. Improving the selected answer.\n  3. Printing the improved answer in its entirety.\n  4. Adding a special marker to the beginning of the improved answer.\n\nThe string also includes a statement encouraging a step-by-step approach\nto ensure the correct answer is found. This function doesn't take any arguments\nand always returns the same string.","ref":"WiseGPTEx.OpenAIUtils.html#resolver_prompt/0"},{"type":"function","title":"Example - WiseGPTEx.OpenAIUtils.resolver_prompt/0","doc":"iex> WiseGPTEx.OpenAIUtils.resolver_prompt()\n    \"You are a resolver tasked with 1) finding which of the X answer options was best 2) improving that answer, 3) printing the improved answer in full, and 4) adding to the begining of the improved answer special marker  . Let's work this out in step by step way to be sure we have the right answer:\"","ref":"WiseGPTEx.OpenAIUtils.html#resolver_prompt/0-example"},{"type":"function","title":"WiseGPTEx.OpenAIUtils.trim_resolver_answer/1","doc":"A function that extracts the resolver's answer from a string.\nThe answer is expected to start within the special marker ` `.\nIf these markers are not found, the function returns the original string.","ref":"WiseGPTEx.OpenAIUtils.html#trim_resolver_answer/1"},{"type":"function","title":"Example - WiseGPTEx.OpenAIUtils.trim_resolver_answer/1","doc":"iex> answer = \"Some text before Hello\"\n    ...> WiseGPTEx.OpenAIUtils.trim_resolver_answer(answer)\n    \"Hello\"","ref":"WiseGPTEx.OpenAIUtils.html#trim_resolver_answer/1-example"},{"type":"extras","title":"WiseGPTEx","doc":"# WiseGPTEx\n\nWiseGPTEx is an Elixir library that utilizes OpenAI's GPT-3.5-turbo model and Anthropic's Claude model to provide intelligent question answering, reasoning capabilities, and AI-generated text completions.","ref":"readme.html"},{"type":"extras","title":"Installation - WiseGPTEx","doc":"1. Add `wise_gpt_ex` to your list of dependencies in `mix.exs`:\n```elixir\ndef deps do\n  [\n    {:wise_gpt_ex, \"~> 0.6.0\"}\n  ]\nend\n```\n\n2. Add the OpenAI and Anthropic API keys to your configuration file (e.g., config/config.exs):\n```elixir\nconfig :wise_gpt_ex, :openai_api_key, \"your_openai_api_key\"\nconfig :wise_gpt_ex, :anthropic_api_key, \"your_anthropic_api_key\"\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage (only with OpenAI API) - WiseGPTEx","doc":"To use WiseGPTEx, simply call the `get_best_completion/2` or `get_best_completion_with_resolver/2` function with a question and optional list of options:\n```elixir\n{:ok, response} = WiseGPTEx.get_best_completion(\"What is the capital of France?\")\n```\n\nYou can also pass options to customize the API request:\n```elixir\nopts = [model: \"gpt-4\", temperature: 0.4, num_completions: 4, timeout: 3_600_000]\n{:ok, response} = WiseGPTEx.get_best_completion_with_resolver(\"What is the capital of France?\", opts)\n```\n\nYou can also make a raw call to the OpenAI API using the `openai_completion/2` function:\n```elixir\nmessages = [\n  %{\"role\" => \"system\", \"content\" => \"You are High School Geography Teacher\"},\n  %{\"role\" => \"user\", \"content\" => \"What was the capital of France in 15th century?\"}\n]\n{ok, response} = WiseGPTEx.openai_completion(messages, [model: \"gpt-4\", temperature: 0.75, timeout: 3_600])\n```\n\nNote that the `get_best_completion_with_resolver/2` function is similar to `get_best_completion/2`.\nThis is because the difference between these two functions is in the method of how they select the best completion, not in their usage or the nature of their inputs or outputs.\nThe `get_best_completion_with_resolver/2` function will perform an additional API call to get a more accurate completion, which can be beneficial for complex or ambiguous queries.\nThe `openai_completion/2` function allows sending a custom conversation to the API without any additional prompting or setting the up the system role etc. This is useful when you want direct access to the model's system messages.","ref":"readme.html#usage-only-with-openai-api"},{"type":"extras","title":"OpenAI API - WiseGPTEx","doc":"For interactions with the OpenAI API, use the `openai_completion/1` function:\n```elixir\n{:ok, response} = WiseGPTEx.openai_completion(\"What is the capital of France?\")\n{:ok, \"Paris\"}\n```","ref":"readme.html#openai-api"},{"type":"extras","title":"Anthropic API - WiseGPTEx","doc":"For interactions with the Anthropic API, use the `anthropic_completion/1` function:\n```elixir\n{:ok, response} = WiseGPTEx.anthropic_completion(\"Why is the sky blue?\")\n{:ok, \"The sky is blue because of the way sunlight interacts with Earth's atmosphere.\"}\n```","ref":"readme.html#anthropic-api"},{"type":"extras","title":"Options - WiseGPTEx","doc":"#","ref":"readme.html#options"},{"type":"extras","title":"Options for the OpenAI API functions: - WiseGPTEx","doc":"- `:model` - The name of the OpenAI model to use (default: \"gpt-3.5-turbo\").\n- `:temperature` - Controls the randomness of the model's output. Higher values result in more diverse responses (default: 0.5).\n- `:num_completions` - The number of completions to generate (default: 3).\n- `:timeout` - The maximum time in milliseconds to wait for a response from the OpenAI API (default: 3_600_000 ms, or 60 minutes).\n\n#","ref":"readme.html#options-for-the-openai-api-functions"},{"type":"extras","title":"Options for the Anthropic API function: - WiseGPTEx","doc":"- `:model` - The version of the Claude model to use (default: \"claude-2\").\n- `:temperature` - Controls the randomness of the model's output (default: 0.1).\n- `:max_tokens_to_sample` - Maximum number of tokens to generate (default: 100,000).\n- `:timeout` - Maximum time in milliseconds to wait for a response (default: 3,600,000 ms, or 60 minutes).","ref":"readme.html#options-for-the-anthropic-api-function"}],"content_type":"text/markdown"}